#
# spec file for package python-zope.deprecation
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-zope.deprecation
Version:        5.1
Release:        2.1
Summary:        Zope Deprecation Infrastructure
License:        ZPL-2.1
URL:            https://pypi.python.org/pypi/zope.deprecation
Source:         https://files.pythonhosted.org/packages/source/z/zope.deprecation/zope_deprecation-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION documentation requirements
BuildRequires:  python3-Sphinx
# /SECTION
%python_subpackages

%description
When we started working on Zope 3.1, we noticed that the hardest part of the
development process was to ensure backward-compatibility and correctly mark
deprecated modules, classes, functions, methods and properties. This package
provides a simple function called 'deprecated(names, reason)' to deprecate the
previously mentioned Python objects.

%package     -n %{name}-doc
Summary:        Zope 3 Deprecation Infrastructure
Provides:       %{python_module zope.deprecation-doc = %{version}}

%description -n %{name}-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n zope_deprecation-%{version}
rm -rf zope_deprecation.egg-info

%build
%pyproject_wheel
sphinx-build -b html docs build/sphinx/html && rm -r build/sphinx/html/.{buildinfo,doctrees}

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v zope.deprecation.tests

%files %{python_files}
%license LICENSE.txt
%doc CHANGES.rst COPYRIGHT.txt README.rst
%dir %{python_sitelib}/zope
%{python_sitelib}/zope[_.]deprecation-%{version}*info
%{python_sitelib}/zope.deprecation-%{version}*-nspkg.pth
%{python_sitelib}/zope/deprecation

%files -n %{name}-doc
%doc build/sphinx/html/

%changelog
* Mon May  5 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Mon Jan 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 5.1
  * Add support for Python 3.12, 3.13.
  * Drop support for Python 3.7, 3.8.
* Tue Jul 25 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Drop sphinx doctrees for reproducible build results
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri May  5 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0:
  * Drop support for Python 2.7, 3.4, 3.5, 3.6.
  * Drop support for deprecated ``python setup.py test``.
  * Add support for Python 3.8, 3.9, 3.10, 3.11.
* Wed Feb  1 2023 Ben Greiner <code@bnavigator.de>
- Implement python packaging best practise: Don't cathall platlib
- Explicitly require python3-Sphinx for building the docs. It could
  have been omitted from %%pythons for %%python_module in a 15.X
  backport project.
* Fri Sep 24 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull in py2 package on doc subpkg
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Apr  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.4.0
  4.3.0
  * Allow custom warning classes to be specified to override the
    default DeprecationWarning.
  * Add support for Python 3.6.
  * Drop support for Python 3.3.
  4.4.0
  * Add support for Python 3.7.
* Sat Jul  8 2017 aloisio@gmx.com
- Update to version 4.2.0
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5.
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.2:
  * Do not require a self parameter for deprecated functions.
    See: https://github.com/zopefoundation/zope.deprecation/pull/1
- additional changes from version 4.1.1:
  * Added explicit support for Python 3.4.
- pass -q to test to avoid spamming the build log
* Fri Feb 28 2014 os-dev@jacraig.com
- Update to 4.1.0:
  * Added a ``Suppressor`` context manager, allowing scoped suppression of
    deprecation warnings.
  * Updated ``boostrap.py`` to version 2.2.
- Update URL (see setup.py).
- Package new CHANGES and README rst files in %%doc.
* Tue Dec 10 2013 p.drouand@gmail.com
- Use download Url as source
* Mon Jul 29 2013 speilicke@suse.com
- Package COPYRIGHT.txt, LICENSE.txt
* Sun Jul 28 2013 hpj@urpla.net
- version 4.0.2: initial build
